---
project: Swiftest
author: David A. Minton
summary: High performance Fortran functions used by the swiftest project via ISO_C_BINDING interfaces and Cython.
project_github: https://github.com/MintonGroup/swiftest
project_download: https://github.com/MintonGroup/swiftest/releases
project_website: https://swiftest.readthedocs.io
github: https://github.com/MintonGroup/
src_dir: src
output_dir: ./docs/_static/fortran_docs
source: true
graph: true
sort: alpha
print_creation_date: true
extra_mods: iso_c_binding:https://gcc.gnu.org/onlinedocs/gfortran/ISO_005fC_005fBINDING.html
            ieee_arithmetic:https://gcc.gnu.org/onlinedocs/gfortran/IEEE-modules.html
            ieee_exceptions:https://gcc.gnu.org/onlinedocs/gfortran/IEEE-modules.html
            iso_fortran_env:https://gcc.gnu.org/onlinedocs/gfortran/ISO_005fFORTRAN_005fENV.html
creation_date: %Y-%m-%d %H:%M %z
md_extensions: markdown.extensions.toc
               markdown.extensions.smarty
---

This is the documentation for the Fortran components of Swiftest
